@@ -46,6 +46,10 @@ import org.junit.jupiter.api.Test;
  */
 public class Base64Test {
 
+    private static final String FOX_BASE64 = "VGhlIH@$#$@%F1aWN@#@#@@rIGJyb3duIGZve\n\r\t%#%#%#%CBqd##$#$W1wZWQgb3ZlciB0aGUgbGF6eSBkb2dzLg==";
+
+    private static final String FOX_TEXT = "The quick brown fox jumped over the lazy dogs.";
+
     private static final Charset CHARSET_UTF8 = StandardCharsets.UTF_8;
 
     /**
@@ -216,6 +220,50 @@ public class Base64Test {
         assertEquals("SGVsbG8gV29ybGQ=", encodedContent, "encoding hello world");
     }
 
+    @Test
+    public void testBuilderCodecPolicy() {
+        assertEquals(CodecPolicy.LENIENT, Base64.builder().get().getCodecPolicy());
+        assertEquals(CodecPolicy.LENIENT, Base64.builder().setDecodingPolicy(CodecPolicy.LENIENT).get().getCodecPolicy());
+        assertEquals(CodecPolicy.STRICT, Base64.builder().setDecodingPolicy(CodecPolicy.STRICT).get().getCodecPolicy());
+        assertEquals(CodecPolicy.LENIENT, Base64.builder().setDecodingPolicy(CodecPolicy.STRICT).setDecodingPolicy(null).get().getCodecPolicy());
+        assertEquals(CodecPolicy.LENIENT, Base64.builder().setDecodingPolicy(null).get().getCodecPolicy());
+    }
+
+    @Test
+    public void testBuilderLineAttributes() {
+        assertNull(Base64.builder().get().getLineSeparator());
+        assertNull(Base64.builder().setLineSeparator(BaseNCodec.CHUNK_SEPARATOR).get().getLineSeparator());
+        assertArrayEquals(BaseNCodec.CHUNK_SEPARATOR, Base64.builder().setLineLength(4).setLineSeparator(BaseNCodec.CHUNK_SEPARATOR).get().getLineSeparator());
+        assertArrayEquals(BaseNCodec.CHUNK_SEPARATOR, Base64.builder().setLineLength(4).setLineSeparator(null).get().getLineSeparator());
+        assertArrayEquals(BaseNCodec.CHUNK_SEPARATOR, Base64.builder().setLineLength(10).setLineSeparator(null).get().getLineSeparator());
+        assertNull(Base64.builder().setLineLength(-1).setLineSeparator(null).get().getLineSeparator());
+        assertNull(Base64.builder().setLineLength(0).setLineSeparator(null).get().getLineSeparator());
+        assertArrayEquals(new byte[] { 1 }, Base64.builder().setLineLength(4).setLineSeparator((byte) 1).get().getLineSeparator());
+        assertEquals("Zm94\r\n", Base64.builder().setLineLength(4).get().encodeToString("fox".getBytes(CHARSET_UTF8)));
+    }
+
+    @Test
+    public void testBuilderPadingByte() {
+        assertNull(Base64.builder().get().getLineSeparator());
+        assertNull(Base64.builder().setLineSeparator(BaseNCodec.CHUNK_SEPARATOR).get().getLineSeparator());
+        assertArrayEquals(BaseNCodec.CHUNK_SEPARATOR, Base64.builder().setLineLength(4).setLineSeparator(BaseNCodec.CHUNK_SEPARATOR).get().getLineSeparator());
+        assertArrayEquals(BaseNCodec.CHUNK_SEPARATOR, Base64.builder().setLineLength(4).setLineSeparator(null).get().getLineSeparator());
+        assertArrayEquals(BaseNCodec.CHUNK_SEPARATOR, Base64.builder().setLineLength(10).setLineSeparator(null).get().getLineSeparator());
+        assertNull(Base64.builder().setLineLength(-1).setLineSeparator(null).get().getLineSeparator());
+        assertNull(Base64.builder().setLineLength(0).setLineSeparator(null).get().getLineSeparator());
+        assertArrayEquals(new byte[] { 1 }, Base64.builder().setLineLength(4).setLineSeparator((byte) 1).get().getLineSeparator());
+        assertEquals("VGhlIGJyb3duIGZveA==", Base64.builder().get().encodeToString("The brown fox".getBytes(CHARSET_UTF8)));
+        assertEquals("VGhlIGJyb3duIGZveA__", Base64.builder().setPadding((byte) '_').get().encodeToString("The brown fox".getBytes(CHARSET_UTF8)));
+    }
+
+    @Test
+    public void testBuilderUrlSafe() {
+        assertFalse(Base64.builder().get().isUrlSafe());
+        assertFalse(Base64.builder().setUrlSafe(false).get().isUrlSafe());
+        assertFalse(Base64.builder().setUrlSafe(true).setUrlSafe(false).get().isUrlSafe());
+        assertTrue(Base64.builder().setUrlSafe(false).setUrlSafe(true).get().isUrlSafe());
+    }
+
     @Test
     public void testByteToStringVariations() throws DecoderException {
         final Base64 base64 = new Base64(0);
@@ -257,6 +305,14 @@ public class Base64Test {
         // TODO Assert??
     }
 
+    /**
+     * Tests <a href="https://issues.apache.org/jira/browse/CODEC-263">CODEC-263</a>.
+     */
+    public void testCodec263() {
+      Base64.decodeBase64("publishMessage");
+      assertTrue(Base64.isBase64("publishMessage"));
+    }
+
     /**
      * Test for CODEC-265: Encode a 1GiB file.
      *
@@ -415,6 +471,55 @@ public class Base64Test {
         assertNotNull(base64);
     }
 
+    @Test
+    public void testCustomEncodingAlphabet() {
+        // created a duplicate of STANDARD_ENCODE_TABLE and replaced two chars with
+        // custom values not already present in table
+        // A => . B => -
+        // @formatter:off
+        final byte[] encodeTable = {
+                '.', '-', 'C', 'D', 'E', 'F', 'G', 'H', 'I', 'J', 'K', 'L', 'M',
+                'N', 'O', 'P', 'Q', 'R', 'S', 'T', 'U', 'V', 'W', 'X', 'Y', 'Z',
+                'a', 'b', 'c', 'd', 'e', 'f', 'g', 'h', 'i', 'j', 'k', 'l', 'm',
+                'n', 'o', 'p', 'q', 'r', 's', 't', 'u', 'v', 'w', 'x', 'y', 'z',
+                '0', '1', '2', '3', '4', '5', '6', '7', '8', '9', '+', '/'
+        };
+        // @formatter:on
+
+        // two instances: one with default table and one with adjusted encoding table
+        final Base64 b64 = new Base64();
+        final Base64 b64customEncoding = Base64.builder().setEncodeTable(encodeTable).get();
+
+        final String content = "! Hello World - this §$%";
+
+        final byte[] encodedBytes = b64.encode(StringUtils.getBytesUtf8(content));
+        final String encodedContent = StringUtils.newStringUtf8(encodedBytes);
+
+        final byte[] encodedBytesCustom = b64customEncoding.encode(StringUtils.getBytesUtf8(content));
+        final String encodedContentCustom = StringUtils.newStringUtf8(encodedBytesCustom);
+
+        assertTrue(encodedContent.contains("A") && encodedContent.contains("B"),
+                "testing precondition not met - ecodedContent should contain parts of modified table");
+
+        assertEquals(encodedContent.replace('A', '.').replace('B', '-') // replace alphabet adjustments
+                .replace("=", "") // remove padding (not default alphabet)
+                , encodedContentCustom);
+
+        // try decode encoded content
+        final byte[] decode = b64customEncoding.decode(encodedBytesCustom);
+        final String decodeString = StringUtils.newStringUtf8(decode);
+
+        assertEquals(content, decodeString);
+    }
+
+    @Test
+    public void testCustomEncodingAlphabet_illegal() {
+        final byte[] encodeTable = {
+                '.', '-', 'C', 'D', 'E', 'F', 'G', 'H', 'I', 'J', 'K', 'L', 'M'
+        };
+        assertThrows(IllegalArgumentException.class, () -> Base64.builder().setEncodeTable(encodeTable).get());
+    }
+
     private void testDecodeEncode(final String encodedText) {
         final String decodedText = StringUtils.newStringUsAscii(Base64.decodeBase64(encodedText));
         final String encodedText2 = Base64.encodeBase64String(StringUtils.getBytesUtf8(decodedText));
@@ -583,10 +688,7 @@ public class Base64Test {
 
     @Test
     public void testIgnoringNonBase64InDecode() throws Exception {
-        assertEquals("The quick brown fox jumped over the lazy dogs.",
-                new String(Base64.decodeBase64(
-                        "VGhlIH@$#$@%F1aWN@#@#@@rIGJyb3duIGZve\n\r\t%#%#%#%CBqd##$#$W1wZWQgb3ZlciB0aGUgbGF6eSBkb2dzLg=="
-                                .getBytes(CHARSET_UTF8))));
+        assertEquals(FOX_TEXT, new String(Base64.decodeBase64(FOX_BASE64.getBytes(CHARSET_UTF8))));
     }
 
     @Test
@@ -643,7 +745,7 @@ public class Base64Test {
 
     @Test
     public void testKnownDecodings() {
-        assertEquals("The quick brown fox jumped over the lazy dogs.", new String(Base64.decodeBase64(
+        assertEquals(FOX_TEXT, new String(Base64.decodeBase64(
                 "VGhlIHF1aWNrIGJyb3duIGZveCBqdW1wZWQgb3ZlciB0aGUgbGF6eSBkb2dzLg==".getBytes(CHARSET_UTF8))));
         assertEquals("It was the best of times, it was the worst of times.", new String(Base64.decodeBase64(
                 "SXQgd2FzIHRoZSBiZXN0IG9mIHRpbWVzLCBpdCB3YXMgdGhlIHdvcnN0IG9mIHRpbWVzLg==".getBytes(CHARSET_UTF8))));
@@ -659,7 +761,7 @@ public class Base64Test {
     @Test
     public void testKnownEncodings() {
         assertEquals("VGhlIHF1aWNrIGJyb3duIGZveCBqdW1wZWQgb3ZlciB0aGUgbGF6eSBkb2dzLg==", new String(
-                Base64.encodeBase64("The quick brown fox jumped over the lazy dogs.".getBytes(CHARSET_UTF8))));
+                Base64.encodeBase64(FOX_TEXT.getBytes(CHARSET_UTF8))));
         assertEquals(
                 "YmxhaCBibGFoIGJsYWggYmxhaCBibGFoIGJsYWggYmxhaCBibGFoIGJsYWggYmxhaCBibGFoIGJs\r\nYWggYmxhaCBibGFoIGJsYWggYmxhaCBibGFoIGJsYWggYmxhaCBibGFoIGJsYWggYmxhaCBibGFo\r\nIGJsYWggYmxhaCBibGFoIGJsYWggYmxhaCBibGFoIGJsYWggYmxhaCBibGFoIGJsYWggYmxhaCBi\r\nbGFoIGJsYWg=\r\n",
                 new String(Base64.encodeBase64Chunked(
